"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const configuration_1 = __importDefault(require("./configuration"));
describe("Configuration", () => {
    describe("Valid", () => {
        it("create with process.env.SENDGRID_API_KEY", () => {
            const env = Object.assign({}, process.env);
            process.env.SENDGRID_API_KEY = "xxx";
            process.env.SENDGRID_FROM_EMAIL = "foo@bar.xyz";
            expect(new configuration_1.default({
                to: { email: "abc@xyz.xyz" },
                template: { filePath: "/templates/main" }
            })).toBeInstanceOf(configuration_1.default);
            process.env = env;
        });
        const configurationData = {
            apiKey: "yyy",
            from: { email: "foo@bar.xyz", name: "foo" },
            to: { email: "abc@xyz.xyz", name: "abc" },
            template: {
                filePath: "/templates/main",
                data: { foo: "bar" },
                wrappers: ["%", "%"]
            }
        };
        it("create with provided apiKey prop", () => {
            expect(new configuration_1.default(configurationData)).toBeInstanceOf(configuration_1.default);
        });
        it("should have apiKey", () => {
            expect(new configuration_1.default(configurationData).apiKey).toEqual("yyy");
        });
        it("should have from", () => {
            expect(new configuration_1.default(configurationData).from).toEqual({
                email: "foo@bar.xyz",
                name: "foo"
            });
        });
        it("should have to", () => {
            expect(new configuration_1.default(configurationData).to).toEqual({
                email: "abc@xyz.xyz",
                name: "abc"
            });
        });
        it("should have template", () => {
            expect(new configuration_1.default(configurationData).template).toEqual({
                filePath: "/templates/main",
                data: { foo: "bar" },
                wrappers: ["%", "%"]
            });
        });
        it("should have suject", () => {
            expect(new configuration_1.default(Object.assign({}, configurationData, { subject: "SUBJECT" })).subject).toEqual("SUBJECT");
        });
    });
    describe("Error", () => {
        it("throws error if no apiKey", () => {
            expect(() => new configuration_1.default({ to: { email: "foo@bar.xyz" } })).toThrow();
        });
        it("throws error if no from email", () => {
            expect(() => new configuration_1.default({
                apiKey: "xxx",
                to: { email: "abc@xyz.xyz" },
                template: { filePath: "/templates/main" }
            })).toThrow();
        });
        it("throws error if no to email", () => {
            expect(() => new configuration_1.default({
                apiKey: "xxx",
                from: { email: "foo@bar.xyz" },
                to: [{ email: "" }],
                template: { filePath: "/templates/main" }
            })).toThrow();
        });
        it("throws error if no to template filePath", () => {
            expect(() => new configuration_1.default({
                apiKey: "xxx",
                from: { email: "foo@bar.xyz" },
                to: { email: "abc@xyz.xyz" },
                template: { filePath: "" }
            })).toThrow();
        });
    });
});
//# sourceMappingURL=configuration.spec.js.map