"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sgClient = require("@sendgrid/client");
const get = require("lodash.get");
const fs = require("fs");
const configuration_1 = __importDefault(require("./configuration"));
const mail_1 = __importDefault(require("./mail"));
class Email {
    constructor(configurationData) {
        this.configuration = new configuration_1.default(configurationData);
        this.client = sgClient;
        this.client.setApiKey(this.configuration.apiKey);
        this.mail = new mail_1.default({
            from: this.configuration.from,
            to: this.configuration.to,
            subject: this.configuration.subject
        });
        if (this.configuration.template) {
            this.mail.setSubstitutionWrappers(get(this.configuration, ["template", "wrappers"], ["{{", "}}"]) // default to {{ }}
            );
            this.setTemplateData(get(this.configuration, ["template", "data"], {}));
            this.setTemplateFile(get(this.configuration, ["template", "filePath"]));
        }
    }
    get personalization() {
        return this.mail.personalizations[0];
    }
    addSubstitution(key, value) {
        this.personalization.addSubstitution(key, value);
    }
    setTemplateFile(filePath) {
        if (!fs.existsSync(filePath)) {
            throw new Error(`[Email.addTemplate] The template file does not exist {path: ${filePath}}.`);
        }
        const value = fs.readFileSync(filePath).toString();
        this.mail.addContent({
            type: "text/html",
            value
        });
    }
    setTemplateData(templateData) {
        Object.keys(templateData).forEach(key => {
            this.addSubstitution(key, templateData[key]);
        });
    }
    send() {
        return this.client
            .request({
            method: "POST",
            url: "/v3/mail/send",
            body: this.mail.toJSON()
        })
            .then(([response]) => {
            // We can confirm the validity or invalidity of the action by checking the response statusCode
            if (response.statusCode !== 202) {
                // TODO: determine the different types of errors we may receive here
                // and throw specific error if we can figure out what went wrong
                // https://sendgrid.com/docs/API_Reference/api_v3.html
                throw new Error("[Email post] received an error response from the sendgrid API.");
            }
        });
    }
}
exports.default = Email;
//# sourceMappingURL=email.js.map